@@ -67,7 +67,9 @@ sub _create
 {
     my $class = shift;
     my $self =
-      $class->SUPER::_create(name => 'openvpn', printableName => __('VPN'));
+      $class->SUPER::_create(name => 'openvpn',
+        domain => 'ebox-openvpn',
+        printableName => __('VPN'));
     bless($self, $class);
     return $self;
 }
@@ -83,8 +85,12 @@ sub modelClasses
     return [
         'EBox::OpenVPN::Model::Servers',
         'EBox::OpenVPN::Model::ServerConfiguration',
-        'EBox::OpenVPN::Model::AdvertisedNetworks',
-
+        {
+          class => 'EBox::OpenVPN::Model::ExposedNetworks',
+          parameters => [
+                         directory => 'AdvertisedNetworks',
+                        ],
+         },
         'EBox::OpenVPN::Model::DownloadClientBundle',
 
         'EBox::OpenVPN::Model::Clients',
@@ -1455,9 +1461,9 @@ sub menu
     my ($self, $root) = @_;
 
     my $folder = new EBox::Menu::Folder(
-                                        'name' => 'VPN',
+                                        'name' => 'OpenVPN',
                                         'text' => $self->printableName(),
-                                        'separator' => __('UTM'),
+                                        'separator' => 'UTM',
                                         'order' => 330
                                        );
 
@@ -1602,10 +1608,6 @@ sub restoreConfig
 }
 
 # log observer stuff
-sub domain
-{
-    return 'ebox-openvpn';
-}
 
 sub logHelper
 {
@@ -1683,4 +1685,47 @@ sub notifyLogChange
     $logs->setAsChanged();
 }
 
+sub report
+{
+    my ($self, $beg, $end, $options) = @_;
+
+    my $report = {};
+
+    $report->{'connections'} = {};
+
+    $report->{'connections'} = $self->runMonthlyQuery($beg, $end, {
+        'select' => 'daemon_type, SUM(connections) AS connections',
+        'from' => 'openvpn_report',
+        'where' => "certificate NOT LIKE '%.ebox-services.com' AND
+                    certificate NOT LIKE '%.ebox-controlcenter.com'",
+        'group' => 'daemon_type'
+    }, { 'key' => 'daemon_type' } );
+
+    $report->{'top_users'} = $self->runQuery($beg, $end, {
+        'select' => 'certificate AS user, SUM(connections) AS connections',
+        'from' => 'openvpn_report',
+        'where' => "daemon_type = 'server'",
+        'group' => 'certificate',
+        'limit' => $options->{'max_top_users'},
+        'order' => 'connections DESC'
+    });
+
+    return $report;
+}
+
+sub consolidateReportQueries
+{
+    return [
+        {
+            'target_table' => 'openvpn_report',
+            'query' => {
+                'select' => 'daemon_name, daemon_type, from_ip AS ip, from_cert AS certificate, COUNT(event) AS connections',
+                'from' => 'openvpn',
+                'where' => "event = 'serverConnectionInitiated'",
+                'group' => 'daemon_name, daemon_type, ip, certificate'
+            }
+        },
+    ];
+}
+
 1;
