@@ -92,7 +92,7 @@ sub _logFilesFromDaemons
     my %logFiles;
 
     foreach my $daemon ($self->{openvpn}->daemons) {
-        next if not $daemon->service;
+        next if not $daemon->isEnabled();
 
         my $file = $daemon->logFile;
         my $name = $daemon->name;
@@ -116,8 +116,8 @@ sub _populateScript
     use strict;
     use warnings;
     use EBox;
-    use EBox::Global; 
-  
+    use EBox::Global;
+
      EBox::init();
     my $openvpn = EBox::Global->modInstance("openvpn");
     my $logHelper = $openvpn->logHelper(noPopulate => 1);
