@@ -273,7 +273,7 @@ sub _validateCerts
                 if (not $file->exist()) {
                     throw EBox::Exceptions::External(
                             __x(
-                                'No file supplied or already setted for {f}',
+                                'No file supplied or already set for {f}',
                                 f => $file->printableName
                                )
                             );
@@ -408,6 +408,16 @@ sub updatedRowNotify
 #     };
 # }
 
+# Method: pageTitle
+#
+#   Overrides <EBox::Model::DataTable::pageTitle>
+#   to show the name of the domain
+sub pageTitle
+{
+        my ($self) = @_;
+
+        return $self->parentRow()->printableValueByName('name');
+}
 
 sub _clientName
 {
