@@ -1,4 +1,5 @@
 # Copyright (C) 2008 Warp Networks S.L.
+# Copyright (C) 2009-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -100,8 +101,7 @@ sub _table
     my $dataTable =
     {
         'tableName'               => __PACKAGE__->nameFromClass(),
-        'printableTableName' => __('Configure bundle'),
-        'pageTitle' => __('Download client bundle'),
+        'printableTableName' => __('Download Client Bundle'),
         'automaticRemove' => 1,
         'defaultController' => '/ebox/OpenVPN/Controller/DownloadClientBundle',
         'defaultActions' => ['add', 'del', 'editField',  'changeView' ],
@@ -138,7 +138,7 @@ sub _clientTypeOptions
                    } ,
                    {
                     value => 'EBoxToEBox',
-                    printableValue => __('EBox to EBox tunnel') ,
+                    printableValue => __('eBox to eBox tunnel') ,
 #                    $EBoxToEBoxTunnel ? () : @disabledAttr,
                    },
 
@@ -297,4 +297,52 @@ sub _help
     return __('A client bundle is a file which contains a ready to use ' .
               'configuration for your clients');
 }
+
+# Method: precondition
+#
+#   Overrides <EBox::Model::DataTable::precondition> to check if the server is
+#   properly configured if it is not we could not download any bundle file
+#
+# Returns:
+#
+#       Boolean - true if the precondition is accomplished, false
+#       otherwise
+sub precondition
+{
+    my ($self) = @_;
+
+    my $configuration = $self->row()->parentRow()->subModel('configuration');
+    defined $configuration or
+        return undef;
+
+    return  $configuration->configured();
+}
+
+# Method: pageTitle
+#
+#   Overrides <EBox::Model::DataTable::pageTitle>
+#   to show the name of the domain
+sub pageTitle
+{
+        my ($self) = @_;
+
+        return $self->parentRow()->printableValueByName('name');
+}
+
+
+# Method: preconditionFailMsg
+#
+#   Overrides <EBox::Model::DataTable::preconditionFailMsg
+#
+# Returns:
+#
+#       String - the i18ned message to inform user why this model
+#       cannot be handled
+#
+#
+sub preconditionFailMsg
+{
+  __('Cannot make a bundle because the server  is not fully configured; please complete the configuration and retry');
+}
+
 1;
