@@ -310,7 +310,7 @@ sub ripDaemon
 {
     my ($self) = @_;
 
-    $self->service()
+    $self->isEnabled()
       or return undef;
 
     $self->pullRoutes()
@@ -394,7 +394,7 @@ sub _confFileLocalParam
     return (local => $localParamValue);
 }
 
-sub service
+sub isEnabled
 {
     my ($self) = @_;
     return $self->_rowAttr('service');
@@ -451,13 +451,14 @@ sub advertisedNets
 
     my $advertisedNetsModel = $self->{row}->subModel('advertisedNetworks');
     my @nets =   map {
-        my $netObj = $_->elementByName('network');
+        my $row = $advertisedNetsModel->row($_);
+        my $netObj = $row->elementByName('network');
         my $net  = $netObj->ip();
         my $maskBits = $netObj->mask();
         my $mask = EBox::NetWrappers::mask_from_bits($maskBits);
 
         [$net, $mask]
-    } @{ $advertisedNetsModel->rows() };
+    } @{ $advertisedNetsModel->ids() };
 
     return @nets;
 }
@@ -564,7 +565,7 @@ sub _deactivate
     $self->{row}->elementByName('service')->setValue(0);
 
    # we stop daemon to not accept more conexions with the invalidate certificate
-    $self->stop() if $self->running();
+    $self->stop() if $self->isRunning();
 }
 
 sub usesPort
@@ -691,10 +692,10 @@ sub summary
     my @summary;
     push @summary, __x('Server {name}', name => $self->name);
 
-    my $service = $self->service ? __('Enabled') : __('Disabled');
+    my $service = $self->isEnabled() ? __('Enabled') : __('Disabled');
     push @summary, (__('Service'), $service);
 
-    my $running = $self->running ? __('Running') : __('Stopped');
+    my $running = $self->isRunning ? __('Running') : __('Stopped');
     push @summary,(__('Daemon status'), $running);
 
     my $localAddress = $self->localAddress();
