@@ -23,7 +23,7 @@ sub createBundleCmds
     my ($class, $bundleFile, $tmpDir, %extraParams) = @_;
 
     my @cmds = (
-        ZIP_PATH . " -j  $bundleFile $tmpDir/*",
+        ZIP_PATH . " -j '$bundleFile' '$tmpDir'/*",
 
     );
 
@@ -45,19 +45,26 @@ sub _installerCmd
     my ($class, $bundleFile) = @_;
     my $installerFile = $class->_windowsClientInstaller();
 
-    return ZIP_PATH . " -g -j $bundleFile $installerFile";
+    return ZIP_PATH . " -g -j '$bundleFile' '$installerFile'";
 }
 
 sub _windowsClientInstaller
 {
-    my $dir = EBox::Config::share() . '/ebox/openvpn';
+    my $dir = EBox::Config::share() . 'ebox/openvpn';
+
+    my @candidates = bsd_glob("$dir/openvpn*install*exe");   # the sort is to
+    if (not @candidates) {
+        throw EBox::Exceptions::Internal("No windows installer found");
+    }
+
 
-    my @candidates =
-      sort bsd_glob("$dir/openvpn*install*exe");   # the sort is to
     # (hopefully ) to sort
     # by version number
 
-    my ($installer) = pop @candidates;
+    my ($installer) = sort @candidates;
+
+
+
     return $installer;
 }
 
